import * as React from 'react';
export interface IScatterPlotDatum {
    x: string;
    y: string;
    datum: any;
}
export interface IScatterPlotProps {
    data: IScatterPlotDatum[];
    width: number;
    height: number;
    domainPadding?: number;
    legendPadding?: number;
    legendFontSize?: number;
    plotPadding?: {
        left: number;
        right: number;
        top: number;
        bottom: number;
    };
    gradientLegendProps?: {
        colors: string[];
        title: string;
        width: number;
        height: number;
        min: number;
        max: number;
    };
    discreteLegendProps?: {
        title: string | string[];
        data: {
            name: string;
            symbol?: {
                fill?: string;
                type?: string;
                size?: number;
            };
            labels?: {
                fill?: string;
                fontSize?: number;
            };
        }[];
    };
    axisLabelTiltAngle?: number;
    disableSelection?: boolean;
    xCategoriesCompare?: (a: string, b: string) => number;
    yCategoriesCompare?: (a: string, b: string) => number;
    theme: {
        axis: {
            style: {
                tickLabels: {
                    fontFamily: string;
                    fontSize: number;
                };
            };
        };
    };
    tooltip?: (d: IScatterPlotDatum) => JSX.Element;
    plotStyle?: any;
    containerStyle?: React.CSSProperties;
    dataComponentSize?: number | ((d: IScatterPlotDatum) => number);
    dataComponentSymbol?: string | ((d: IScatterPlotDatum) => string);
}
export declare class ScatterPlot extends React.Component<IScatterPlotProps, {}> {
    static defaultProps: Partial<IScatterPlotProps>;
    private container;
    private tooltipHelper;
    constructor(props: IScatterPlotProps);
    get mouseEvents(): {
        target: string;
        eventHandlers: {
            onMouseOver: () => {
                target: string;
                mutation: (props: any) => {
                    active: boolean;
                };
            }[];
            onMouseOut: () => {
                target: string;
                mutation: () => {
                    active: boolean;
                };
            }[];
        };
    }[];
    get tooltipModel(): any;
    get pointHovered(): boolean;
    get xCategories(): string[];
    get yCategories(): string[];
    get bottomPadding(): number;
    get leftPadding(): number;
    get rightPadding(): number;
    get padding(): {
        left: number;
        right: number;
        top: number;
        bottom: number;
    };
    get gradientLegendProps(): {
        gradientId: string;
        fontSize: number | undefined;
        colors: string[];
        x: number;
        y: number;
        title: string;
        width: number;
        height: number;
        min: number;
        max: number;
    };
    get discreteLegendProps(): {
        x: number;
        y: number;
        titleComponent: JSX.Element;
        centerTitle: boolean;
        orientation: string;
        rowGutter: number;
        symbolSpacer: number;
        title: string | string[];
        style: {
            title: {
                fontSize: number | undefined;
                padding: number;
            };
        };
        data: {
            labels: {
                fontSize: number | undefined;
                fill?: string | undefined;
            };
            name: string;
            symbol?: {
                fill?: string | undefined;
                type?: string | undefined;
                size?: number | undefined;
            } | undefined;
        }[];
    } | undefined;
    get dataWithTooltip(): IScatterPlotDatum[];
    render(): JSX.Element;
    private containerRef;
}
export default ScatterPlot;
