/// <reference types="react" />
import { defaultSortMethod } from 'cbioportal-utils';
export declare enum FrequencyTableColumnEnum {
    TUMOR_TYPE = "tumorType",
    MUTATION_STATUS = "mutationStatus",
    SAMPLE_COUNT = "tumorTypeCount",
    VARIANT_COUNT = "variantCount",
    PREVALENCE_FREQUENCY = "frequency",
    BIALLELIC_RATIO = "biallelicRatio",
    MEDIAN_AGE_AT_DX = "ageAtDx",
    MEDIAN_TMB = "tmb",
    MSI_SCORE = "msiScore",
    MEDIAN_HRD_LST = "lst",
    MEDIAN_HRD_NTELOMERIC_AI = "ntelomericAi",
    MEDIAN_HRD_FRACTION_LOH = "fractionLoh",
    OVERALL_NUMBER_OF_GERMLINE_HOMOZYGOUS = "overallNumberOfGermlineHomozygous",
    NUMBER_OF_GERMLINE_HOMOZYGOUS = "numberOfGermlineHomozygous"
}
export declare function columnHeader(headerContent: string | JSX.Element, overlay: JSX.Element | string): JSX.Element;
export declare const FREQUENCY_TABLE_HEADER_COMPONENT: {
    [id: string]: JSX.Element;
};
export declare const FREQUENCY_COLUMNS_DEFINITION: {
    tumorType: {
        id: FrequencyTableColumnEnum;
        Cell: typeof renderTextData;
        Header: JSX.Element;
        accessor: FrequencyTableColumnEnum;
        minWidth: number;
        Footer: JSX.Element;
    };
    mutationStatus: {
        id: FrequencyTableColumnEnum;
        Cell: typeof renderTextData;
        Header: JSX.Element;
        accessor: FrequencyTableColumnEnum;
        minWidth: number;
    };
    tumorTypeCount: {
        id: FrequencyTableColumnEnum;
        Cell: typeof renderNumber;
        Header: JSX.Element;
        accessor: FrequencyTableColumnEnum;
        minWidth: number;
        Footer: (col: any) => JSX.Element;
    };
    variantCount: {
        id: FrequencyTableColumnEnum;
        Cell: typeof renderNumber;
        Header: JSX.Element;
        accessor: FrequencyTableColumnEnum;
        minWidth: number;
        Footer: (col: any) => JSX.Element;
    };
    numberOfGermlineHomozygous: {
        id: FrequencyTableColumnEnum;
        Cell: typeof renderNumber;
        Header: JSX.Element;
        accessor: FrequencyTableColumnEnum;
        sortMethod: typeof defaultSortMethod;
        minWidth: number;
        Footer: (col: any) => JSX.Element;
    };
    frequency: {
        id: FrequencyTableColumnEnum;
        Cell: (cell: any) => JSX.Element;
        Header: JSX.Element;
        accessor: FrequencyTableColumnEnum;
        sortMethod: typeof defaultSortMethod;
        minWidth: number;
        Footer: (col: any) => JSX.Element;
    };
    biallelicRatio: {
        id: FrequencyTableColumnEnum;
        Cell: typeof renderPercentage;
        Header: JSX.Element;
        accessor: FrequencyTableColumnEnum;
        sortMethod: typeof defaultSortMethod;
        minWidth: number;
        Footer: (col: any) => JSX.Element;
    };
    ageAtDx: {
        id: FrequencyTableColumnEnum;
        Cell: typeof renderNumber;
        Header: JSX.Element;
        sortMethod: typeof defaultSortMethod;
        accessor: FrequencyTableColumnEnum;
        minWidth: number;
    };
    tmb: {
        id: FrequencyTableColumnEnum;
        Cell: (column: any) => JSX.Element;
        Header: JSX.Element;
        sortMethod: typeof defaultSortMethod;
        accessor: FrequencyTableColumnEnum;
        minWidth: number;
    };
    msiScore: {
        id: FrequencyTableColumnEnum;
        Cell: typeof renderNumber;
        Header: JSX.Element;
        sortMethod: typeof defaultSortMethod;
        accessor: FrequencyTableColumnEnum;
        minWidth: number;
    };
    lst: {
        id: FrequencyTableColumnEnum;
        Cell: typeof renderNumber;
        Header: JSX.Element;
        sortMethod: typeof defaultSortMethod;
        accessor: FrequencyTableColumnEnum;
        minWidth: number;
    };
    ntelomericAi: {
        id: FrequencyTableColumnEnum;
        Cell: typeof renderNumber;
        Header: JSX.Element;
        sortMethod: typeof defaultSortMethod;
        accessor: FrequencyTableColumnEnum;
        minWidth: number;
    };
    fractionLoh: {
        id: FrequencyTableColumnEnum;
        Cell: typeof renderFrequency;
        Header: JSX.Element;
        sortMethod: typeof defaultSortMethod;
        accessor: FrequencyTableColumnEnum;
        minWidth: number;
    };
};
export declare function renderPercentage(cellProps: any, styles?: any): JSX.Element;
export declare function renderNumber(cellProps: any, fractionDigits?: number): JSX.Element;
export declare function renderFrequency(cellProps: any): JSX.Element;
export declare function renderTextData(cellProps: any): JSX.Element;
